@@ -5,7 +5,7 @@ use Data::Dumper;
 #Oh dear, she's stuck in an infinite loop and he's an idiot! Oh well, that's love
 
 BEGIN {
-    $Mojolicious::Plugin::Routes::Restful::VERSION = '0.02';
+    $Mojolicious::Plugin::Routes::Restful::VERSION = '0.03';
 }
 use Mojo::Base 'Mojolicious::Plugin';
 
@@ -60,9 +60,12 @@ sub register {
 
     my $config = $args->{CONFIG};
     my $rapp   = $app->routes;
+    $rapp = $args->{ROUTE}
+      if (exists($args->{ROUTE}));
+    
     my $routes = $args->{PARENT};
 
-    $rapp->namespaces( $config->{'NAMESPACES'} );
+    $app->routes->namespaces( $config->{'NAMESPACES'} );
 
     foreach my $key ( keys( %{$routes} ) ) {
 
@@ -108,7 +111,7 @@ sub _make_routes {
 
     my $route_stash = $route->{STASH} || {};
 
-    $route_stash = { %{$route_stash}, %{$parent_stash} }
+    $route_stash = { %{$parent_stash}, %{$route_stash}  }
       if ($parent_stash);
     my $action     = $route->{ACTION}     || "show";
     my $controller = $route->{CONTROLLER} || $key;
@@ -350,12 +353,12 @@ sub _sub_api_routes {
           . $url
           . "/:id/$child_resource/:child_id->Via->PATCH-> $contoller_prefix-$child_controller#update"
       )
-      if ( $verbs->{PATCH} )
+      if ( $verbs->{UPDATE} )
       and ( $api->{DEBUG} );
 
     $rapi->route( "/" . $url . "/:id/" . $child_resource . "/:child_id" )
       ->via('PATCH')->to( "$contoller_prefix-$child_controller#update", $stash )
-      if ( $verbs->{PATCH} );
+      if ( $verbs->{UPDATE} );
 
     warn(   "API CHILD   ->/" 
           . $url
@@ -417,7 +420,7 @@ or just routes or just a RESTful API.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -579,6 +582,7 @@ Via for this in most places.
 You define which routes and the behaviour of your routes with a simple config hash in the startup section of your app.  The plugin returns the route object
 it created so you will have it if you need it for other operations, such as add in a bunch of collective DELETE routes. 
 
+
 =head2 CONFIG
 
 This controls the global settings. 
@@ -592,6 +596,11 @@ Used to hold the namespaces for all routes you generate. Does the same thing as
 It must be an array ref of module Class names as they would appear in a 'use' statement.  These are important, as your app may not find 
 your class if its  namespace do not appear here.
 
+=head2 ROUTE
+
+With this optional attribute you can pass in a route that will have all the generated as its children. This is useful if you want to use 
+a bridge or callback on all your generated routes. 
+
 =head3 Resource Types PARENT, CHILD, INLINE
 
 There is nothing in Mojolicious stopping you from creating a big goofy chained resource like 'all/the/bad/code/perl/catalyst'; if that is what you want, then
@@ -742,8 +751,8 @@ By default, all route types use the GET http method.  You can change this to any
 HTTP methods.  As this plugin has a restful portion, this is probably not advisable.
 
   PARENT => {
-            user    => {Via =>[qw(POST PUT),
-                        ACTION=>'update']}
+            user    => {VIA    =>[qw(POST PUT),
+                        ACTION =>'update']}
           }
 
 would yield these routes
@@ -1111,7 +1120,7 @@ So this hash
                        },
                     INLINE => 
                        { resume=>{
-                          API => {RESOURCE => resume,
+                          API => {RESOURCE => 'resume',
                                   ACTION=>'get_or_update_resume',
                                   VERBS=>{RETRIEVE => 1,
                                           UPDATE   => 1}
@@ -1210,8 +1219,8 @@ So given this hash
                        CHILD => {
                          user => {
                            API => {
-                             CONTROLLER = 'my_users',
-                             RESOURCE   = 'user',
+                             CONTROLLER => 'my_users',
+                             RESOURCE   => 'user',
                              VERBS => {
                                CREATE   => 1,
                                RETRIEVE => 1,
@@ -1270,8 +1279,8 @@ So with this hash
                        CHILD => {
                          user => {
                            API => {
-                             CONTROLLER = 'my_users',
-                             RESORUCE   = 'user',
+                             CONTROLLER => 'my_users',
+                             RESORUCE   => 'user',
                              VERBS => {
                                CREATE   => 1,
                                RETRIEVE => 1,
@@ -1321,8 +1330,8 @@ So this hash
                        CHILD => {
                          user => {
                            API => {
-                             CONTROLLER = 'my_users',
-                             RESORUCE   = 'user',
+                             CONTROLLER => 'my_users',
+                             RESORUCE   => 'user',
                              VERBS => {
                                CREATE   => 1,
                                RETRIEVE => 1,
@@ -1368,8 +1377,8 @@ attribute as in the hash below
                        CHILD => {
                          user => {
                            API => {
-                             CONTROLLER = 'my_users',
-                             RESORUCE   = 'user',
+                             CONTROLLER => 'my_users',
+                             RESORUCE   => 'user',
                              VERBS => {
                                CREATE   => 1,
                                RETRIEVE => 1,
